# Todo

## To Do

[ ] Add logging
[ ] Add documentation

## In Progress

[ ] Add comments to the code
[ ] Improve code structure
[ ] Add help message for command line arguments that do not already have them

## Completed

[x] Improve command line arguments
